==> haskell-casa-client-0.0.3-22-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.3
visibility:           public
id:                   casa-client-0.0.3-IMwiZeo8KyaD5bz8GZCtq4
key:                  casa-client-0.0.3-IMwiZeo8KyaD5bz8GZCtq4
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Client for Casa
description:
    Client for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  7b18f8662a1167f69707b28b4406cd7f
exposed:              True
exposed-modules:      Casa.Client
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.3-IMwiZeo8KyaD5bz8GZCtq4
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base16-bytestring-1.0.2.0-ARBAmNNbyxLEDoUwDjra0R
    bytestring-0.11.5.3 casa-types-0.0.3-9s1eRoPqUMAI0rFVV9RayN
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    conduit-extra-1.3.8-Dg42smPzbiF4Nemzj9bTg6
    crypton-1.0.4-8iIZddQo7Y8B1JLRcnCUbI exceptions-0.10.7
    http-conduit-2.3.9.1-4fv8UoY8zTlKlPGaK7tn4g
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-client-0.0.3-24-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.3
visibility:           public
id:                   casa-client-0.0.3-5q0ft9NCUZMJevPnOBynhg
key:                  casa-client-0.0.3-5q0ft9NCUZMJevPnOBynhg
license:              BSD-3-Clause
copyright:
    2018-2019 FP Complete,
    2024-2025 Haskell Foundation

maintainer:
    Chris Done <chrisdone@fpcomplete.com>,
    Mike Pilgrem <public@pilgrem.com>

author:               Chris Done
homepage:             https://github.com/commercialhaskell/casa#readme
synopsis:             Client for Casa
description:
    Client for Casa (Content-Addressable Storage Archive). See
    <https://casa.stackage.org/>

category:             Development
abi:                  6badbd12d35c5892c09325d0720d7dce
exposed:              True
exposed-modules:      Casa.Client
import-dirs:          /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/casa-client-0.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.3-5q0ft9NCUZMJevPnOBynhg
depends:
    aeson-2.2.0.0-Hqy1Zqe0ZE81dk2L20icmH
    attoparsec-0.14.4-8hLS1m777hPFjiaInp95BL base-4.18.2.1
    base16-bytestring-1.0.2.0-6gPusxqn90AJxFEjBUebK6
    bytestring-0.11.5.3 casa-types-0.0.3-6udvvxQQfEiCYWZ8F7dVAo
    conduit-1.3.6.1-CwUx671uWmDAcHwxI0YYDy
    conduit-extra-1.3.8-GHF5wYhQp30HUaLAtCbs0G
    crypton-1.0.4-37TsNQoV8Vb5042LlXS4MC exceptions-0.10.7
    http-conduit-2.3.9.1-4XCjseDTPMR1cOfyxjAQAe
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-uri-2.6.4.2-1aRZPUfkmMD8JwUJF5GqMA
    resourcet-1.2.6-JtO0n9rtgTt543EMYn7K77 template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.6-IRGSsrKtWq3BZSHvMwfeE6
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-1hrud2F05KV7Rz7RsKTZ5O

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
